/*
  Inspired by Eliha Meeks' tutorial
  https://medium.com/@Elijah_Meeks/interactive-applications-with-react-d3-f76f7b3ebc71

*/
import { scaleLinear } from 'd3-scale'
import { max } from 'd3-array'
import { select } from 'd3-selection'

/*
  Props:
    - data
    - size
    - barFillStyle
    - barBorderStyle
*/
class BarChart extends React.Component {
   constructor(props){
      super(props)
      this.createBarChart = this.createBarChart.bind(this)
   }

   componentDidMount() {
      this.createBarChart()
   }

   componentDidUpdate() {
      this.createBarChart()
   }

   createBarChart() {
      const node = this.node
      const dataMax = max(this.props.data)
      const yScale = scaleLinear()
         .domain([0, dataMax])
         .range([0, this.props.size[1]])

     select(node)
        .selectAll('rect')
        .data(this.props.data)
        .enter()
        .append('rect')

     select(node)
        .selectAll('rect')
        .data(this.props.data)
        .exit()
        .remove()

     select(node)
        .selectAll('rect')
        .data(this.props.data)
        .style('fill', this.props.barFillStyle||'rgb(250,50,20)')
        .style('stroke', this.props.barStrokeStyle||'rgb(250,50,20)')
        .attr('x', (d,i) => i * 12)
        .attr('y', d => this.props.size[1] - yScale(d))
        .attr('height', d => yScale(d))
        .attr('width', 5)
   }

render() {
      return <svg ref={node => this.node = node}
      width={this.props.size[0]} height={this.props.size[1]}>
      </svg>
   }
}
export default BarChart
